function [ss, indx] = ttce_ss(x, parmf,parmU,parmT, talent, parmtt ,index , q ,dfA)
% Steady state of  talent to task model (2020.06.04)
% talent to task model  of  competitive equilibrium
% tpdf : talent pdf
% threshold is a cutpoint to determine who belong to  S workers;
% dfA : distribution of asset holding
global delta_s delta_e beta 

alpha = parmf(1);
 
tau_ks =parmT(1,1); tau_ke = parmT(1,2);
tau_n =parmT(1,3) ;  G     =parmT(1,4);

 

Theta = talent(:,1);
PI = talent(:,2);
 
pu = parmtt(:,:,1);  
ps = parmtt(:,:,2);
zu  = lprod(Theta,pu); zs   = lprod(Theta,ps);


Ks =x(1);
zNu =x(2); % aggregate labor supply of unskilled labor
Ke  =x(3);
zNs =x(4); % aggregate "effective" labor supply of skilled labor
C = x(5) ;   % Aggregate consumption
phi = x(6:end); % length of phi should be equal to length(Theta);

 [Y, rs, re, ws, wu] = korv1([Ks, zNu, Ke, zNs], parmf);
[PC,PNu,PNs] = PNweight(phi, parmU,  talent, parmtt ,index ) ;
c = PC*C;
Uindx = (1:index-1)';  PI_U = sum(PI(Uindx).*zu(Uindx) ) ;
Sindx = (index: length(Theta))'; PI_S = sum(PI(Sindx).*zs(Sindx) ) ; 

cu = c(Uindx);
cs = c(Sindx);

nu =1- PNu*(PI_U - zNu); nu=nu(Uindx);
ns = 1- PNs*(PI_S- zNs); ns=ns(Sindx);
ugrid = ones( length(Uindx),1);
sgrid = ones(length(Sindx),1);

[~,ucu,vnu] = util1([cu,nu],parmU);
[~,ucs,vns] = util1([cs,ns],parmU);

 
% % Transfer, budget balance condition 
 Tr = tau_n*(ws*zNs+wu*zNu) + ...
      tau_ks*(rs-delta_s)*Ks+...
      tau_ke*(re - delta_e/q)*Ke -...
      G*Y;  %Lump-sum transfer
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% % Nonlinear equation systems
% 
 if alpha ==0
 ss1(1) = Ks; 
 else
 ss1(1)= 1+(1-tau_ks)*(rs-delta_s) - 1/beta ;
 end

% Intratemporal condition:
suintr = vnu + (1-tau_n).*zu(Uindx).*wu.*ucu;
ssintr =  vns + (1-tau_n).*zs(Sindx).*ws.*ucs;


% Euler equation of Ke

ss1(2) = 1+(1-tau_ke)*(q*re - delta_e) -1/beta ;
 

ks = dfA.*Ks;
ke = dfA.*Ke;

ss1(3) = mean(suintr);
ss1(4) = mean(ssintr);
ss1(5) = Y - C -delta_s*Ks - delta_e*Ke/q - G*Y ;
w = [wu*ugrid ; ws*sgrid];
z = [zu(Uindx); zs(Sindx)];
 

% budget constraint
bgc =  Tr + (1-tau_ks)*(rs-delta_s)*ks +...
            (1-tau_ke)*(re- delta_e/q)*ke+ ...
            (1-tau_n).*z.*w.*[nu;ns] -c;
 
% Resource constraint:
ss =[ss1'; bgc];

gama_u = pu(1); psi_u = pu(2);
gama_s = ps(1); psi_s = ps(2);

if gama_s == gama_u
    if ws*exp(psi_s) > wu*exp(psi_u)
        indx =1;
    else
        indx =[];
    end
else
    indx =  max( floor((log(wu/ws) + psi_u - psi_s)/(gama_s - gama_u)),0 )+2;    
end


end