function [f, allocation, tax] = Trans_IC( x, parmf, parmU, parmP, K0 ,...
                                    pist, piut,zst,zut,qt)
%Mirrlees tax transitional dynamics

global   delta_s delta_e beta


psis = parmP(1) ;    %  including  population ratio
psiu = parmP(2) ;    % 
G = parmP(3);         % Government expenditure


T = length(qt);        
Lambda_s = x(end);


% Final and initial steady state;
Ksi=K0(1);  % Initial capital stock Ks
Kei=K0(2);  % Initial capital stock Ke

% Transisitonal variables , initially given                
x        = reshape(  x(1:end-1), T, 5);
Kst    = [Ksi ; x(1:end-1,1)];   
%Kst_ld = x(:,1);
zNut = x(:,2);                   
Ket   = [Kei ; x(1:end-1,3)];       
%Ket_ld =x(:,3);
zNst = x(:,4);              
Ct     = x(:,5);                  

Kst_ld = fop(Kst);
Ket_ld = fop(Ket);

% Define factor price
xst = pist.*zst;
xut = piut.*zut;

xx =[Kst,zNut,Ket,zNst];
 
[Y, rs, re, ws, wu] = korv1(xx ,parmf);
[xi, xi_Nu0, xi_Ke, xi_Ns0] = wp1(xx, parmf, zst, zut);
xi_nu = xi_Nu0.*xut;
xi_ns = xi_Ns0.*xst;
tolt = 1e-6;

if parmU(end) ==1
    nst = min(zNst./(xst),1-tolt);  % individual
    nut = min(zNut./(xut),1-tolt);
else
    nst = min(zNst./(xst),1-tolt);  % individual
    nut = min(zNut./(xut),1-tolt);
end

% consumption ratio of skilled and unskilled

[os,ou] =cratio([psis + Lambda_s , psiu - Lambda_s], pist,piut, parmU);

cs = os.*Ct;
cu = ou.*Ct;

% Utility and marginal utility
[Uss, ucs, vns] = util1([cs, nst] ,parmU);
[~ , ucu, vnu] = util1([cu, nut] ,parmU);
[Usu, ~ , vnsu]= util1([cu, nut./xi] ,parmU);

Gammas = (psis + Lambda_s).*ucs ./ pist ;
Gammau = (psiu - Lambda_s).*ucu ./piut ;
Gamma = (Gammas + Gammau  )/2 ; % In fact Gammas = Gammau
 
MRS = Gamma./(fop(Gamma).*beta);

if parmf(1) ==0
    f1 = Kst_ld ;
else    
    Euqs =  Gamma.*(rs + 1- delta_s); 
    f1= Gamma - beta.* fop(Euqs) ;   % with depreciation allowence
end

xiic =  - Lambda_s.*vnsu;  % positive part;


f2= xut.*Gamma.*wu +...                    % unskilled workers
       xiic.*(1./xi - nut./(xi.^2).*xi_nu)...
     + psiu.*vnu ;

 
Euqe =  Gamma.*(re + (1-delta_e)./qt  )  -  xiic.*(nut./xi.^2 .* xi_Ke) ;
f3=  beta.*  fop(Euqe) - Gamma./qt;    %capital equipment


f4= Gamma.*xst.*ws  - xiic.*(  nut./(xi.^2) .* xi_ns)...
    +(psis + Lambda_s).*vns;    %skilled workers


f5= (1-G)*Y+(1-delta_s)*Kst+ (1./qt).*(1-delta_e).*Ket -...
        (Ct  + Kst_ld + (1./qt).*Ket_ld) ;   % resource constraint; 

% check IC constraint
 Vss = inf_sum(Uss,beta);
 Vsu = inf_sum(Usu,beta);

f6 =    Vss - Vsu;


f = [f1;f2;f3;f4;f5;f6];


% Allocations
allocation.Ks = Kst;
allocation.Nu=zNut;   % aggregate labor supply of unskilled labor
allocation.Ke=Ket;
allocation.Ns=zNst;   % aggregate labor supply of skilled labor
allocation.C = Ct ;
allocation.cs = cs; allocation.cu = cu;
allocation.ns = nst;  allocation.nu = nut;
allocation.wp = xi;
 
rs_ld = fop(rs);
re_ld = fop(re);
q_ld = fop(qt) ;
 

tax.s =  1+ vns./(ucs.*ws.*zst) ;
tax.u =  1+ vnu./(ucu.*wu.*zut);
tax.ks = (1-MRS)./(rs_ld -delta_s) +1 ;
tax.ke = (1-MRS.*q_ld./qt )./(q_ld.*re_ld - delta_e) +1;

Reld = fop(re -delta_e./qt);
tax.ke2 =( 1./q_ld - MRS./qt)./Reld +1 ;
 






end

