function [f, trd_new,alc,tax] = Trans_ICtt3( x, parmf, parmU, parmP, talent, parmtt,...
                                     iniK ,q, trd, IC_delta,ctind)                
% Dynamic assignment model of  Mirrlees (20210316)
global   delta_s delta_e beta


psi  = parmP.weight;   %  Pareto weight length(psi) = length(PI); 
Gr   = parmP.G ; 

T = length(q); M = size(talent,1);
Theta = talent(:,1);  PI = talent(:,2);

pu = parmtt(:,:,1);   
ps = parmtt(:,:,2);

zu  = lprod(Theta,pu);  %    NxT matrix
zs   = lprod(Theta,ps);   %   NxT matrix

cdelta = Theta(2) - Theta(1);
index =    floor((trd - Theta(1))/cdelta)+2   ;  % transform threshold to index
 
% Final and initial steady state;
Ksi=iniK(1);  % Initial capital stock Ks
Kei=iniK(2);  % Initial capital stock Ke

Ksp = x(1:T);
Kep = x(T+1:2*T);
C = x(2*T+1:3*T);
n = reshape(x(3*T+1:  3*T+M*T),M,T);  %reshape the 
Ks =[Ksi; Ksp(1:end-1)] ;  Ke = [Kei; Kep(1:end-1)];
nln = length(IC_delta);  % number of binding constraint
Lambda=x(end-nln+1:end) ;

Lambda_ext = [zeros(M-nln,1); Lambda; 0]; %  M+1 array



[Sindx, Uindx, PIS, PIU] = indf(index', PI);
Ls = sum(PIS.*zs.*n)';  Lu = sum(PIU.*zu.*n)';
u = [Ks, Lu, Ke,Ls];
[Y, rs, re, ws, wu] = korv1(u,parmf);
% [xi,xi_Lu,xi_Ke, xi_Ls] = wp1(u,parmf,zs,zu) ;
 


% Adjusted weight of consumption
Cweight =   (psi.*PI + Lambda_ext(1:end-1) - Lambda_ext(2:end))./PI;
[PC,~,~ ] =PNweight(Cweight, parmU,  talent, parmtt ,index' );
c = PC.*repmat(C',M,1);
gamma_c = parmU(1);
Gamma = mean(Cweight.*c.^(-gamma_c))';
 
W = zs.*PIS.*ws' + zu.*PIU.*wu';
 
% FOC on  labor 


%[Udiff, dICf] = ICfun(c,n, u, Lambda_ext(2:end), parmf, parmU, talent, parmtt, index);
[Udiff, dICf] = ICfun2(c,n, u, Lambda_ext(1:end-1), parmf, parmU, talent, parmtt, index);
%[Udiff2, dICf2] = ICfun(c,n, u, Lambda_ext(2:end), parmf, parmU, talent, parmtt, index);
[~,  uc,  un] = util_mat(c,n, parmU) ;
VA =  (PI.*psi + Lambda_ext(1:end-1)).* un ;
VB =  Gamma'.*W; 
VC =-dICf.n;

% Is this  a  matrix !?
ff2  = VA+VB+VC;
 
% Systems of equations
% % Euler equation: Capital structure

 EuqKs = Gamma.*(rs+1-delta_s);
 EuqKe =Gamma.*(re +(1-delta_e)./q )+ dICf.Ke';
 
 
 if parmf(1) ==0
 ff1 = Ks;    
 else
 ff1 =  beta.*fop(EuqKs) - Gamma;
 end


% % Euler equation: Capital equipment
ff4 = beta*fop(EuqKe) - Gamma./q;
 

% % Resource constraint
ff3 = (1-Gr)*Y +(1- delta_s)*Ks+(1-delta_e)*Ke./q ...
         -C - fop(Ks) - fop(Ke)./q;            
           
% IC constraint check     
Udf = Udiff(end-nln+1:end)';  % Difference between mimic and truthful telling
ff5 = Udf + IC_delta; 

ff6Ks = diff(Ksp(end-15:end))*10;
ff6Ke = diff(Kep(end-15:end))*10;

f =[ff1(:); ff2(:) ;ff3(:); ff4(:); ff5(:);ff6Ks;ff6Ke];



gama_s = ps(:,1); psi_s  =ps(:,2);
gama_u = pu(:,1);psi_u = pu(:,2); 


trd_new0 = min( max( (log(wu./ws )  +  psi_u - psi_s )./(gama_s - gama_u) , ...
                                    Theta(1) + 1e-3) , Theta(end) - 1e-3) ;  

trd_new = set_monotonic(trd_new0,ctind);                                
 
ind_new = t2ind(trd_new,talent);
 
    Gamma_ld = fop(Gamma);
    MRS =  Gamma./(Gamma_ld*beta) ;
    rs_ld = fop(rs);
    re_ld = fop(re);
    q_ld = fop(q) ;
 

% Allocation and tax rates
tax.ks = (1-MRS)./(rs_ld -delta_s) +1 ;

DA = (1-delta_e)./q_ld +re_ld- MRS./q; 
DB=  fop(-dICf.Ke'./Gamma);  DK = DA*0.2+DB*0.8; % deal with comuptation error;
tax.ke =DK./(re_ld - delta_e./q_ld);
 
ww = zs.*Sindx.*ws' + zu.*Uindx.*wu';
tax.n =  1+ un./(uc.*ww) ;
FPI = cumsum(PI);
Sratio1 = 1 - FPI(index-1);                      
NS = sum(PIS.*n)';  NU = sum(PIU.*n)';
ZS = (Ls./NS);  ZU = (Lu./NU);
sp_model= ZS.*ws./(ZU.*wu) ;
alc.Ksp = Ksp;
alc.Kep=Kep;
alc.Ls = Ls;
alc.Lu =Lu;
alc.Ns = sum(n.*PIS,1)';
alc.Nu = sum(n.*PIU,1)';
alc.ZS = Ls./alc.Ns;
alc.C =C;
alc.c =c;
alc.n =n;
alc.Lambda = Lambda;
alc.sp= sp_model;
alc.sr = Sratio1;
alc.Y = Y;
taus = (sum(tax.n.*n.*PIS.*ww)./sum((ww.*PIS.*n)))';
tauu = (sum(tax.n.*n.*PIU.*ww)./sum(ww.*PIU.*n))';
LFU = inf_sum(util_mat(c,n,parmU)' ,beta )  ;
alc.SW =sum(PI.*LFU'.*psi);
alc.index= index;
alc.bnd =  Udiff(1)';
tttaxL = sum(tax.n.*n.*PIS.*ww + tax.n.*n.*PIU.*ww ,1)'./ ...
               sum(ww.*n.*PI,1)';
tax.L = tttaxL;           

% sum((tax.n.*n.*PIS.*ww + tax.n.*n.*PIU.*ww)  ./ww,1)';

end


function y = set_monotonic(trd, ctind)
% ironing  the trheshold, avoiding threshold fluctuation
% given the node ctind
TT = length(trd);
trdd = ones(TT,1);
NN = length(ctind);
for jj =2:NN
    ind = (ctind(jj-1):ctind(jj))';
    trdd(ind)  = mean(trd(ind));
end
trdd(ind(end)+1:TT) = trdd(ind(end));
y = trdd;
end