function [ss, allocation, IC_check] = ssfb_korv(x , parmf,parmU,parmP,pis,piu,zs,zu,q)
% Non-linear equation systems in steady statein the economy of KORV technology
global delta_s delta_e beta

 
psis  = parmP(1);  % weight x population ratio
psiu =parmP(2) ;  % weight x population ratio
Gr   = parmP(3) ; 


% The variables we have to solve,
Ks=x(1);
zNu=x(2);   % aggregate labor supply of unskilled labor
Ke=x(3);
zNs=x(4);  % aggregate effective labor supply of skilled labor
C=x(5);

% Define cs, cu, ns, nu
[os, ou] = cratio([psis, psiu],pis,piu,parmU);
cs = os*C; 
cu = ou*C;

xs = pis*zs ;
xu = piu*zu;
tol1 = 1e-7;

vflag  = parmU(4);
if  vflag== 1
    nu  = min(zNu/(xu),1-tol1);
    ns  = min(zNs/(xs),1-tol1);
else
    ns  = zNs/(xs);
    nu  = zNu/(xu);
end
 

[~,ucs,vns, ~,~] = util1([cs,ns],parmU);
[~,ucu,vnu, ~,~] = util1([cu,nu],parmU);
u =[Ks, zNu, Ke, zNs];
[Y, rs, re, ws,wu] = korv1(u, parmf) ;


if  parmf(1)  ==0
ss(1) = Ks;    
else
ss(1) = rs+1-delta_s-1/beta ;     % Euler equation of capital structure
end

ss(2) = ucu*zu*wu +  vnu ;              % intratemporal condition of unskilled worker 
ss(3) = q*re+1-delta_e -1/beta;       % Euler equation of capital equipment 
ss(4) = ucs*zs*ws + vns ;                % intratemporal condition of skilled worker  
ss(5) = (1-Gr)*Y-delta_s*Ks-(delta_e/q)*Ke-C;    % resource constraint



allocation.Ks = Ks;
allocation.Nu=zNu;   % aggregate labor supply of unskilled labor
allocation.Ke=Ke;
allocation.Ns=zNs;   % aggregate labor supply of skilled labor
allocation.cs=cs;  % skilled worker's consumption share
allocation.cu =cu; % unskilled worker's consumption share
allocation.C = pis*cs + piu*cu;
allocation.ns = zNs./(pis.*zs) ;
allocation.nu = zNu./(piu.*zu);
wp = ws./wu .*(zs/zu);

Uss = util1([cs,ns],parmU);   Usu = util1([cu, nu./wp],parmU);
Vss = Uss./(1-beta) ;  Vsu = Usu./(1-beta);
IC_check = max(Vss- Vsu); % To make sure IC constraint binding, must be negative

end

