function [ss, trd_new, IC, alc] = ssfb_korv_tt(x , parmf,parmU,parmP, talent, parmtt ,q , trd)
% Non-linear equation systems in steady statein the economy of KORV technology
global delta_s delta_e beta

 
psi  = parmP.weight;   %  Pareto weight length(psi) = length(PI); 
Gr   = parmP.G ; 

Theta = talent(:,1);  PI = talent(:,2);
M = size(talent,1);

pu = parmtt(:,:,1);   
ps = parmtt(:,:,2);

zu  = lprod(Theta,pu);  %    NxT matrix
zs   = lprod(Theta,ps);   %   NxT matrix

 
index =   t2ind(trd,Theta);  % transform threshold to index 

% The variables we have to solve,
Ks=x(1);
Lu=x(2);   % aggregate labor supply of unskilled labor
Ke=x(3);
Ls=x(4);  % aggregate effective labor supply of skilled labor
C=x(5);
 
u =[Ks, Lu, Ke, Ls];
[Y, rs, re, ws,wu] = korv1(u, parmf) ;


 
% dimension of  PC, PNu, PNs should be equal to  NPI x T
[Sindx, Uindx, PIS, PIU] = indf(index, PI);
gamma_c = parmU(1);   gamma_n = parmU(2);

PHI_C  =  sum(  PI.*  psi.^(1/gamma_c) ).^gamma_c;

qpsis =  min(psi./zs, 1/eps) ; qpsiu = min( psi./zu, 1/eps);
qpis  = PI.*zs; qpiu = PI.*zu;

PHI_Ls =   sum(qpis.* qpsis.^(1/gamma_n).*Sindx).^(gamma_n);
PHI_Lu =  sum(qpiu.* qpsiu.^(1/gamma_n).*Uindx).^(gamma_n);

PIZS = sum(PIS.*zs); 
PIZU = sum(PIU.*zu);
[~,UC,VLs] = util1([C,Ls],parmU, PIZS);
[~,~,VLu] = util1([C,Lu], parmU, PIZU);
 
Gamma = PHI_C* UC;

if  parmf(1)  ==0
ss(1) = Ks;    
else
ss(1) = rs+1-delta_s-1/beta ;     % Euler equation of capital structure
end

ss(2) =  PHI_Lu*VLu + Gamma.*wu ;               % intratemporal condition of unskilled worker 
ss(3) = q*re+1-delta_e -1/beta;       % Euler equation of capital equipment 
ss(4) =   PHI_Ls*VLs + Gamma.*ws ;            % intratemporal condition of skilled worker  
ss(5) = (1-Gr)*Y-delta_s*Ks-(delta_e/q)*Ke-C;    % resource constraint
ss=ss';

% threshold check;
gama_s  = ps(:,1);   psi_s  = ps(:,2);
gama_u =  pu(:,1);  psi_u  = pu(:,2);
trd_new  = min( max( (log(wu/ws )  +  psi_u - psi_s )/(gama_s - gama_u) , Theta(1)) , Theta(end));



%%%%%%%%%%  Check IC constraint   %%%%%%%%%%%%
[PC,PLu,PLs] = PNweight(psi, parmU,  talent, parmtt ,index' ) ;                                            
c = PC.*repmat(C',M,1);   % MxT matrix
ZPI_U =  repmat(sum(PIU.*zu,1),M,1).*Uindx; % 
ZPI_S =  repmat(sum(PIS.*zs ,1), M, 1).*Sindx;
ZLS = repmat(Ls', M,1).*Sindx;
ZLU=  repmat(Lu', M,1).*Uindx;
n  = 1-(PLu+PLs).*(  ZPI_U+ZPI_S  -  ZLS-ZLU );  % M x T matrix


% Define  effective wage z*w
WS = repmat(ws, 1,M)';
WU = repmat(wu,1,M)';
ewage = zs.*WS.*Sindx + zu.*WU.*Uindx;

c_true = c(2:end, :);  % (M-1) x T  matrix
n_true = n(2:end,:);
c_mic = c(1:end-1,:) ;  
n_mic =  ewage(1:end-1,:).*n(1:end-1,:)./ewage(2:end,:);


V_true = [0,inf_sum(util_mat(c_true,n_true,parmU)',beta)]';
V_mimic =[0, inf_sum(util_mat(c_mic, n_mic,parmU)',beta)]';
IC.diff = V_true-V_mimic;  % M-1  array
IC.indu = min(find(IC.diff<0)) -1 ;

alc.Ks =Ks;
alc.Ke = Ke;
alc.C =C;
alc.n = n;




end