function  [ drs, dre,  dws, dwu]  = dkorv1(x0, parmf, varargin)
%The production function of Krusell, Ohanion, Rios-Rull, Violante 
%(2000, Econometrica)
% Z :  TFP
if nargin ==2
    Z =1 ;
else
    Z = varargin{1};
end
 % x : [Ks, Nu, Ke, Ns]
 
 alpha = parmf(1);  sigma = parmf(2);
 mu = parmf(3);  rho = parmf(4); lambda = parmf(5);
 
 Ks = x0(:,1); Nu = x0(:,2);
 Ke =  x0(:,3); Ns =  x0(:,4);
 
 B =  (lambda.*Ke.^rho + (1-lambda).*Ns.^rho).^(1./rho) ; 
 A =  (mu.*Nu.^sigma + (1-mu).*B.^sigma).^(1./sigma);
 
 
 dA_dNu = mu* (Nu./A).^(sigma -1 ) ;
 dA_dB   = (1-mu)*(B./A).^(sigma-1);
 dB_dNs =(1-lambda)*(Ns./B).^(rho-1);
 dB_dKe = lambda*(Ke./B).^(rho-1);
 
[~, rs, re, ws, wu] = korv1(x0, parmf, Z);


drs.Ks  =  (alpha-1)* rs./Ks;
drs.Ke  =  (1-alpha)*rs./A .* dA_dB .* dB_dKe;
drs.Nu = (1-alpha)*rs./A .*  dA_dNu;
drs.Ns  =  (1-alpha)*rs./A.* dA_dB .* dB_dNs ;


dre.Ks = alpha * re./Ks; 
dre.Nu =  (1-alpha-sigma)*re./A .* dA_dNu;
dre.Ns = (1-alpha-sigma).*re./A .* dA_dB .* dB_dNs +...
                (sigma-rho).*re./B .* dB_dNs ;            

%dre.Ke = (1-alpha-sigma).*re./A .* dA_dB .* dB_dNs +...
%               (sigma-rho).*re./B .* dB_Ke ;   

% We can use auto_diff to verify the result
 dwu.Ks = alpha* wu./Ks;
 dwu.Ke = (1-alpha -sigma)*(wu./A).*dA_dB.*dB_dKe;
 dwu.Ns = (1-alpha -sigma)*(wu./A).*dA_dB.*dB_dNs;
 dwu.Nu = (1-alpha-sigma)*(wu./A).*dA_dNu + ...
                   (sigma-1).*wu./Nu;


% Use auto diff to verify the result;
dws.Ks = alpha*ws./Ks;
dws.Nu = (1-alpha-sigma)* ws./A .* dA_dNu;
dws.Ke  = (1-alpha-sigma)*ws./A.*dA_dB.*dB_dKe + ...
                                 (sigma-rho)*ws./B .*dB_dKe          ;
dws.Ns  = (1-alpha-sigma)*ws./A.*dA_dB.*dB_dNs + ...
                                 (sigma-rho)*ws./B .*dB_dNs +...
                                  (rho-1).*ws./Ns;

 

end

