function  [Y, rs, re, ws, wu]  = korv1(x, param, varargin)
%The production function of Krusell, Ohanion, Rios-Rull, Violante 
% Z :  TFP
if nargin ==2
    Z =1 ;
else
    Z = varargin{1};
end

alpha = param(1);
sigma = param(2) ;  mu = param(3);
rho = param(4)     ;  lambda = param(5);

Ks = x(:,1); Nu = x(:,2);
Ke = x(:,3); Ns = x(:,4);


% CES between  Ke and Ns :
if rho ==0
    B = Ke.^lambda .* Ns.^(1-lambda) ;
else
    B =  (lambda.*Ke.^rho + (1-lambda).*Ns.^rho ).^(1/rho) ;
end

B_Ke =  lambda *(Ke./B).^(rho-1) ;
B_Ns = (1-lambda)*(Ns./B).^(rho-1);

% CES between  Nu and  B
if sigma==0
    A =  Nu.^mu .* B.^(1-mu);
else
    A = (mu.*Nu.^sigma  + (1-mu).*B.^sigma).^(1/sigma) ;
end

A_Nu = mu*(Nu./A).^(sigma-1);
A_B =  (1-mu)*(B./A).^(sigma-1);


% Cobb-Douglas between Ks and A
if alpha ==0
    Y = Z.*A;
    rs =0 ;
else
    Y = Z.*Ks.^alpha .* A.^(1-alpha);
    Y_Ks  = alpha*(Y./Ks) ;
    rs =   Y_Ks;
end

Y_A   =  (1-alpha)*(Y./A);
re =  Y_A.*A_B.*B_Ke ;  % apply chain rule
ws = Y_A.*A_B.*B_Ns;
wu = Y_A.*A_Nu;

end