function y = solve_Ramsy1(x ,parmf, parmU, parmP , inik0, pist,piut, zst , zut, qt )
% skill depending tax case,  2020.04.06
% Add two implementability constriant and lump sum transfer

global    delta_s    delta_e    beta

 
psis =parmP(1);
psiu =parmP(2);
G = parmP(3);
tk = parmP(4);  % initial capital tax rates

%alpha = parmf(1);    % [ alpha ;  sigma; mu ; rho ; lambda]
T = size(qt,1);   % T must larger than 1

XX =  reshape(x(1:end-4), T,5);
Ksp =  XX(:,1); zNu = XX(:,2);
Kep = XX(:,3); zNs =XX(:,4);
C = XX(:,5);


% consumption share
os =  x(end-3) ;
ou = (1 - os*pist )/piut;

% Implementability multipliers  (skill, unskill)
theta_s = x(end-2);  
theta_u = x(end-1);
LT = x(end) ;  % inidividual  lump-sum transfer


% Initial Asset definition inik0 = [kss0 , ksu0 ; kes0 , keu0] ;
kss0 = inik0(1,1);  kes0 = inik0(1,2);  
ksu0 =inik0(2,1);  keu0 = inik0(2,2);

Ks0 = kss0*pist + ksu0*piut;
Ke0 = kes0*pist + keu0*piut;
Ks = [Ks0; Ksp(1:T-1)];
Ke = [Ke0; Kep(1:T-1)];

 

% Factor Prices  and initial return
x0 =[Ks ,  zNu, Ke,  zNs];
[Y, rs,re, ws,wu] = korv1(x0, parmf);

Rs0  =(1+           (1-tk)*(rs(1)  -delta_s));
Re0  =(1/qt(1) +(1-tk)*(re(1)  - delta_e/qt(1) )) ;


% Marginal Utility function ( consumption and Labor) and Utility
xst = pist.*zst  ;  xut = piut.*zut;


toln = 1e-7;
vflag = parmU(4);
if vflag ==1
    ns = min(1-toln,zNs./(xst)); % individual skilled labor supply
    nu = min(1-toln,zNu./(xut)); % individual unskilled labor supply
else
    ns = zNs./xst;
    nu =zNu./xut;
end

 


cs = os*C      ;  cu = ou*C;

[~, ucs, vns,  ~ , vnns]  = util1([cs,ns] ,parmU);
[~, ucu, vnu, ~, vnnu] = util1([cu,nu],parmU);

els_s  =  vns ./  (vnns.* ns); 
els_u  =  vnu ./ (vnnu.* nu); 

[~,UC , ~, UCC,~] = util1([C, zeros(T,1)], parmU);
% Marginal utility of consumption
gamma_c = parmU(1);
 
hctt  =   [os^(1-gamma_c) , ou^(1-gamma_c)] *...
             [psis+(1-gamma_c)*theta_s ;   psiu+(1-gamma_c)*theta_u]  ;
dhctt =  (1-gamma_c)*[os^(-gamma_c) , -ou^(-gamma_c)]*...
                                   [psis+(1-gamma_c)*theta_s ;   psiu+(1-gamma_c)*theta_u] ;

                   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial asset term on derivative
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



xos = [os;ou];
thetaa = [theta_s ; theta_u];
[ HC, dHC_os, HC0, dHC0_os] = hct(xos, thetaa , parmU, parmP, pist, piut)   ;      

xx0 = [Ks(1),zNu(1), Ke(1), zNs(1) ];  % initial  value
 
% Initial asset and its derivative
[ A0 ,   dA_Ns,  dA_Nu  ] = iniA0( xx0, inik0, parmf, qt(1),LT,tk);

% initial term is   HC0A0 , derivative on 
UC0 = UC(1);  % initial marginal utility of consumption
UCC0 = UCC(1);

dAos = dHC0_os*UC0*A0;
dAC0 = [ HC0*UCC0*A0   ;zeros(T-1,1)] ;

Ans0 =   HC0*UC0*dA_Ns.*xst(1) ;  % FOC on initial period, HC0 contain theta_s, theta_u
Anu0 =   HC0*UC0*dA_Nu.*xut(1);
Ans = [Ans0; zeros(T-1,1)];
Anu = [Anu0; zeros(T-1,1)];

ucAs0=ucs(1)*A0(1);
ucAu0=ucu(1)*A0(2);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Derivative of Ramsey
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


Gamma = HC.*UC - dAC0;  % derivate on C; 



% Intratemporal conditions 
fns = ( psis + theta_s* (1+  1./els_s)  ).*vns -  Ans  ...
            +Gamma.*ws.*xst  ;

fnu =( psiu + theta_u* (1+  1./els_u)  ).*vnu -  Anu  ...        
            +Gamma.*wu.*xut ;

        
% FOC on equipment and capital

Euke = Gamma.*(re + (1-delta_e)./qt);
Euks = Gamma.*(rs + (1-delta_s) );


fke =  - Gamma./qt  + beta.* fop(Euke);

fks =  -Gamma + beta*fop(Euks) ;

% Resource constraint
 
frc = (1-G)*Y   + (1-delta_e)*Ke./qt  + (1-delta_s)*Ks - C  -Kep./qt - Ksp  ;



% Lump-sum tax criterion :
%implementability conditions and derivative on T 
Es  = impbc1([cs,ns], parmU); % flag: check steady state
Eu =  impbc1([cu,nu], parmU);


% Implementability constraint
fips =  Es - ucAs0;
fipu = Eu - ucAu0;
LFUC = inf_sum(UC.*C./(1-gamma_c) , beta);
fos = dHC_os*LFUC - dAos ;  % LFU : life-time utility of consumption


% flt  % lump-sum transfer
flt = theta_s*ucs(1) + theta_u*ucu(1) ;
 y =[fns; fnu; fke; fks; frc; fips; fipu ; fos; flt ] ;

 
end