function [y, trd_new] = solve_Ramsy1_tt(x ,parmf, parmU, parmP, parmtt, ...
                                                    talent, iniK, dfA, qt ,trd )
% skill depending tax case,
% Add implementability constriants and lump sum transfer
% dfA is an Nx1 array
global    delta_s    delta_e    beta

T = size(qt,1);   % Define time horizon,  t >1


G = parmP.G ;
tk = parmP.tk ;  % initial capital tax rates


% Type  and probability
Theta = talent(:,1);  PI = talent(:,2);
cdelta =Theta(2) - Theta(1);  % difference between two type
typeN = size(talent,1);


% Variables to solve : x
LT = x(end) ;  % inidividual  lump-sum transfer
XX2 = reshape(x(5*T+1:end-1),typeN,2);
phi =XX2(:,1);        %market weight
Psi = XX2(:,2);        % multiplier of implementability constraint;

XX =  reshape(x(1:5*T), T,5);
Ksp =  XX(:,1); Lu = XX(:,2);
Kep = XX(:,3);  Ls =XX(:,4);
C = XX(:,5);
index =    floor((trd - Theta(1))/cdelta)+2   ;


% Type to productivity : 
pu = parmtt(:,:,1);   ps = parmtt(:,:,2);
zu  = lprod(Theta,pu);  %    NxT matrix
zs   = lprod(Theta,ps);   %   NxT matrix

 
% Initial Asset definition inik0 = [kss0 , ksu0 ; kes0 , keu0] ;
Ks0 = iniK(1); Ke0 = iniK(2);
Ks = [Ks0; Ksp(1:T-1)];
Ke = [Ke0; Kep(1:T-1)];
%dfA = phi/sum(PI.*phi);
ks0 =  Ks0*dfA;   % initial distribution of Ks holding  %dfA = phi/sum(PI.*phi);
ke0 =  Ke0*dfA;   % initial distribution of Ke holding

 
% Factor Prices   
x0 =[Ks ,  Lu, Ke,  Ls];
[Y, rs,re, ws,wu] = korv1(x0, parmf);



% Use phi to find out  individual consumption and labor supply;
 [Sindx, Uindx, PIS, PIU] = indf(index', PI);
 [PC,PLu,PLs] = PNweight(phi, parmU,  talent, parmtt ,index' ) ;
ZPI_U =  repmat(sum(PIU.*zu,1),typeN,1).*Uindx; % 
ZPI_S =  repmat(sum(PIS.*zs ,1), typeN, 1).*Sindx;
ZLS = repmat(Ls', typeN,1).*Sindx;
ZLU=  repmat(Lu', typeN,1).*Uindx;
c = PC.*repmat(C',typeN,1);
n  = 1-(PLu+PLs).*(  ZPI_U+ZPI_S  -   ZLS-ZLU     );  

 
 
 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial asset term on derivative
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Rs0  =(1+  (1-tk)*(rs(1)  -delta_s));
Re0  =(1/qt(1) +(1-tk)*(re(1)  - delta_e/qt(1) )) ;
iniAsset = Rs0*ks0 + Re0*ke0 + LT;
xx0 = [Ks(1),Lu(1), Ke(1), Ls(1) ];  % initial  value
 
% Initial asset and its derivative
[ A0 ,   dA_Ls,  dA_Lu  ] = iniA0_tt( xx0, dfA, parmf, qt(1),LT,tk);



% Aggregate FOC on  C, LS, LU and Pareto_Negishi weight
PI_ZS = sum(PIS.*zs)';
PI_ZU =sum(PIU.*zu)';
[~,  UC,  VL_S,  UCC, VLL_S] = util1([C,Ls], parmU, PI_ZS) ;
[~,  ~,  VL_U,  ~, VLL_U] = util1([C,Lu], parmU, PI_ZU) ;
[~, PHI_RC, PHI_RC0,...
   ~, PHI_RL, PHI_RL2] = PNweight_R(phi, Psi ,parmU,parmP,  talent, ...
                                                                 parmtt ,index , A0 );
 

% initial term is   HC0A0 , derivative on
UC0 = UC(1);  % initial marginal utility of consumption
UCC0 = UCC(1);

HC0 =  sum(PHI_RC0.f.*A0);
dAC0 = [ HC0*UCC0  ;zeros(T-1,1)] ;


ALS0 =    sum(PHI_RC0.f .* dA_Ls)* UC0;
ALU0 =   sum(PHI_RC0.f.*dA_Lu)*UC0  ;
ALs =  [ALS0; zeros(T-1,1)];
ALu =  [ALU0; zeros(T-1,1)];


 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Derivative of Ramsey
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

HC = PHI_RC.f;
Gamma = HC.*UC - dAC0;  % derivate on C; 



% Intratemporal conditions 
fLS = PHI_RL.sf' .*VL_S  + PHI_RL2.sf'.* VLL_S -ALs +  Gamma.*ws  ;
fLU = PHI_RL.uf' .*VL_U + PHI_RL2.uf' .* VLL_U - ALu +  Gamma.*wu;

        
% FOC on equipment and  srtucture
Euke = Gamma.*(re + (1-delta_e)./qt);
Euks = Gamma.*(rs + (1-delta_s) );

fke =  - Gamma./qt  + beta.* fop(Euke);
fks =  -Gamma + beta*fop(Euks) ;

% Resource constraint
 frc = (1-G)*Y   + (1-delta_e)*Ke./qt  + (1-delta_s)*Ks - C  -Kep./qt - Ksp  ;

% Lump-sum tax criterion :
%implementability conditions and derivative on T

 
Exp  = impbc1_tt(c,n, parmU);     % flag: check steady state
iniA0 = UC0* (PHI_RC0.f2 ).*A0 ;

fimp = Exp -iniA0;
% Implementability constraint
 
% FOC on phi part
gamma_c = parmU(1);
gamma_n = parmU(2);
lpw = -(1-gamma_n)/gamma_n;
cpw =-(1-gamma_c)/gamma_c;
 

dphi_c =  PHI_RC.df;
dphi_s = PHI_RL.dsf'  ;
dphi_u = PHI_RL.duf' ;
dphi_s2 = PHI_RL2.dsf'  ;
dphi_u2 =PHI_RL2.duf' ;

LFUC = inf_sum(UC.^(cpw)  , beta)./(1-gamma_c)  .* dphi_c  ;
LFVLS= inf_sum(   (-VL_S).^(lpw).*dphi_s , beta)'./(1-gamma_n)  ;
LFVLU = inf_sum(   (-VL_U).^(lpw).*dphi_u ,beta)'./(1-gamma_n)  ;
LFVLS2= inf_sum(   VL_S.*dphi_s2 , beta)'  ;
LFVLU2 = inf_sum(  VL_U.*dphi_u2 ,beta)'  ;
LFUC0 = UC0*PHI_RC0.df;


fphi = LFUC + LFVLS + LFVLU + ...
           LFVLS2 + LFVLU2 - ...
           LFUC0 ;

fphi2 = (sum(PI.*phi) -1)  ;       
% flt  :  lump-sum transfer
flt =   sum( PI.*Psi ./ phi)   ; %theta_s*ucs(1) + theta_u*ucu(1) ;


% Index checking;
gama_s = ps(:,1); psi_s  =ps(:,2);
gama_u = pu(:,1);psi_u = pu(:,2); 

% index_s = the number of exceeding theta_new
trd_new = min( max( (log(wu./ws )  +  psi_u - psi_s )./(gama_s - gama_u) , ...
                                    Theta(1) + 1e-3) , Theta(end) - 1e-3) ;  
 

y =[fLS; fLU; fke; fks; frc; fimp; fphi; flt  ;fphi2] ;

 
end