function ss = SS_korv(x, parmf,parmU,parmT, ...
                                         pis, piu,zs,zu, q ,ssk )
% Non-linear equation systems in steady state in the economy of KORV
% technology 
global delta_s delta_e beta

tau_ks = parmT(1,1) ;  % Capital tax
tau_ke =parmT(1,2) ;
tau_n =parmT(1,3) ;  % Labor tax
Gr =parmT(1,4) ;



% The variables we have to solve,
Ks=x(1);
zNu=x(2);   % aggregate labor supply of unskilled labor
Ke=x(3);
zNs=x(4);   % aggregate labor supply of skilled labor
cs=x(5);  % skilled worker's consumption 
cu =x(6); % unskilled worker's consumption 

C = pis*cs + piu*cu ;       % aggregate consumption
suk =   (1-ssk*pis)/piu ;   %  asset holding proportion for unskilled workers

xs = pis*zs;   xu = piu*zu;

 vflag  = parmU(4);
%transform aggregate labor supply to individual;
tol1 = 1e-7;
if vflag ==1     % i.e., u(c)+v(1-n)=c^(1-gamma_c)/(1-gamma_c)+chi (1-n)^(1-gamma_n)/(1-gamma_n)
nu = min(zNu/(xu),1-tol1);  
nu=max(0,nu);
ns = min(zNs/(xs),1-tol1); 
ns=max(0,ns);
else                % i.e., u(c)-v(n)=c^(1-gamma_c)/(1-gamma_c)-chi (n)^(1+gamma_n)/(1+gamma_n)
nu = zNu/(xu); 
nu=max(0,nu);
ns = zNs/(xs);  
ns=max(0,ns);
end


% Factor price      
 u  = reshape(x(1:4),1,4);   
[ Y , rs, re, ws, wu] = korv1(u, parmf);

% Transfer, budget balance condition
Tr = (tau_n*(ws*zNs+wu*zNu) + ...
       tau_ks*(rs-delta_s)*Ks+...
       tau_ke*(re- delta_e/q)*Ke -...
       Gr*Y)  / (pis + piu) ;  %Lump-sum transfer divided by total number of workers


kss=ssk*Ks; % Ks holding of skilled labor
kes= ssk*Ke; % Ke holding of skilled labor
ksu=suk*Ks; % Ks holding of uskilled labor
keu=suk*Ke; % Ke holding of unskilled labor

% Marginal utility
[~, ucs,vns] = util1([cs,ns] ,parmU);
[~, ucu, vnu] = util1([cu,nu],parmU);

% First order conditions
if  parmf(1)  ==  0
    ss(1) = Ks ;
else
    ss(1)= 1+(1-tau_ks)*(rs-delta_s) - 1/beta ;    % Euler equation of capital structure
end

ss(2)= ucu*(1-tau_n)*wu*zu + vnu;                    % labor leisure condition of unskilled worker
ss(3)= 1+(1-tau_ke)*(q*re - delta_e) -1/beta ;   % Euler equation of capital equipment
ss(4)= ucs*(1-tau_n)*ws*zs + vns;                       % labor leisure of skilled worker
ss(5)= Tr + (1-tau_ks)*(rs-delta_s)*kss +...          %budget constraint of skilled worker
    (1-tau_ke)*(re- delta_e/q)*kes +...
    (1-tau_n)*ws*zs*ns  -cs ;
ss(6)= Tr  + (1-tau_ks)*(rs-delta_s)*ksu +...    % budget constraint of unskilled worker
    (1-tau_ke)*(re- delta_e/q)*keu +...
    (1-tau_n)*wu*zu*nu  -cu;

ss =ss(:);

end

