% Calibration step
%Set  Initial guess of allocation
Ks0 = 0.2392;    Ke0 = 0.2809;
ns0 = 0.3036;    nu0 = 0.3030;
zNs0 = ns0*zs0*pis0;  zNu0 = nu0*zu0*piu0;
cs0 = 0.1574;  cu0 = 0.15;  % consumption
x000 =[Ks0;zNu0;Ke0;zNs0;cs0;cu0];
option0 =optimset('Display','off','MaxIter',100,...
      'TolFun',1e-8); 

%Initial guess for calibration
[guess0, err0] =fsolve('SS_korv',x000,option0,parmf0,parmU,parmT,...
                                               pis0, piu0,zs0,zu0,q0 ,ssk);   

 
% Calibrate the parameters
y0 =[mu0;  lambda0;chi];  % Parameters we have to find
tol2 = 1e-3;
ub0= [1-tol2 1-tol2   10  ];               %upper bound of y0 
lb0 =[tol2+0.01,  tol2+0.01    0    ]; %lower bound
x0 =[Ks0;zNu0;Ke0;zNs0;cs0;cu0];
option1 = optimset('Display','on',...
   'MaxIter',200,'TolFun',1e-8,'LargeScale','on');
parmff0 =[alpha;sigma;rho];

x00 = guess0;
moment.sp = 1.4737;        %1963: 1.4737
moment.ky = 2.694;          %1963: 2.2724
moment.rkgdp = 0.3;        %1963:  0.3
moment.cy = 0.6;               %1963:   0.59
moment.iy =  0.162;
moment.isie = 0.4861;
parmU0 = parmU(1:2);

% Use lsqnonlin function to find 
[par, resnorm2]=lsqnonlin(@calimod, y0, lb0, ub0, option1, x00,parmff0,parmU,parmT,...
                                               pis0, piu0, zs0,zu0,q0,ssk,moment);
mu = par(1); lambda = par(2); chi=par(3);
[~,mom]=calimod(par,x00,parmff0,parmU,parmT, pis0, piu0, zs0,zu0,q0 ,ssk,moment);


% x00 is defined in calibration.m,  q2t is colleted from data.mat
q = q2t/q2t(1) ;   
qth = hpfilter(q,100);
parmf = [alpha;sigma;mu;rho;lambda] ;  % final  parmf
[ss0,err_ss0] = fsolve('SS_korv',x00,option0,parmf,parmU,parmT,pis0,piu0,...
                              zs0,zu0, q(1) , ssk);  % SS_korv
 
                          
Kss0 = ss0(1); Nus0= ss0(2);
Kes0 = ss0(3); Nss0 = ss0(4); 
Css0 = ss0(5)*pis0 +ss0(6)*piu0;                       
T = size(q,1);
 
% Print the calibration result and parameters (Table 1 and 2)
fprintf('\n \n \n')
disp('========Table 1 Initial Moment Conditions======')
fprintf('Target                     Data         Model \n')
disp('===============================================')
fprintf(' %10s             %4.3f        %4.3f   \n','Skill premium:' ,[moment.sp,  mom.sp])
fprintf(' %10s      %2.1f          %2.1f \n','Capital income share:',[moment.rkgdp, mom.rkgdp])
fprintf(' %10s  %2.1f          %2.1f   \n','Consumption output share:',[moment.cy, mom.cy])
fprintf(' %10s      %3.2f         %3.2f    \n','Capital output ratio:',[moment.ky, mom.ky])
fprintf(' %10s   %4.3f        %4.3f    \n','Investment output ratio:',[moment.iy, mom.iy])
fprintf(' %10s                 %4.3f        %4.3f\n','Is/Ie:', [moment.isie, mom.isie])
disp('===============================================')


fprintf('\n \n \n \n \n')
disp('=======Table 2.  Parameter Values===========')
fprintf('Parameters                     Value \n')
fprintf('%10s                %3.2f \n','Discount factor',beta)
fprintf('%10s    %2.2f\n','Elas of intep substitution ',1/gamma_c  )
fprintf('%10s  %2.2f \n','Elas substitution of leisure ',1/gamma_n)
fprintf('%10s               %4.2f \n','Elas of Nu & Ke ' ,1/(1-sigma))
fprintf('%10s               %4.2f \n','Elas of Ns & Ke ',1/(1-rho))
fprintf('%10s          %3.2f \n','Depreciation rate Ks ',delta_s)
fprintf('%10s          %4.3f \n','Depreciation rate Ke ',delta_e)
fprintf('%10s         %4.3f  \n','U.S Capital tax rates ',tau_k)
fprintf('%10s            %4.3f \n','U.S Labor tax rate ',tau_n)
fprintf('%10s              %4.3f \n','Gov. Exp. ratio  ',Gr)
fprintf('%10s            %4.3f \n','Income share of Nu ',mu)
fprintf('%10s           %4.3f \n','Income share of Ke  ',lambda)
fprintf('%10s       %3.2f \n','Util. weight of leisure ',chi)
disp('============================================')
fprintf('\n \n \n \n \n')




function [par, mom] = calimod( y, inivalue , parmf0, parmU0 ,parmT, ...
                                                    pis,piu,zs,zu,q, ssk, moment)
% We follow He and Liu (2008)  calibration step
global delta_s delta_e  
mu  =y(1);  lambda = y(2); 
chi= y(3); %
alpha  = parmf0(1);
sigma = parmf0(2);
rho = parmf0(3);

parmff = [alpha;sigma;mu;rho;lambda] ;
parmU= [parmU0;chi;1];
%  This is a key step to make the function stable


option1 = optimset('Display','off','MaxIter',100);
x0 = inivalue;

[sol, ~] = fsolve('SS_korv',x0,option1,parmff,parmU,parmT,...
    pis,piu,zs,zu,q , ssk);


% Targets:
sp =  moment.sp ;          %1963: 1.4737
rkgdp = moment.rkgdp;
cy = moment.cy;

% check if getting imaginary solutions
if isreal(sol) ==0
    disp('You get a wrong answer')
    return
else
    Ks =sol(1);
    zNu = sol(2);
  Ke =sol(3);
  zNs =sol(4);
 cs =sol(5);
cu =sol(6);
 C = pis*cs+piu*cu;
 va =[Ks,zNu,Ke,zNs]  ; % local variable: first four allocation
 
[Y, rs, re, ws, wu] = korv1(va, parmff);
 
% Three moment conditions :
par(1)= (zs*ws)/(wu) - sp ;    %wage premium
par(2)= (re*Ke + rs*Ks)/Y - rkgdp; %capital income share
par(3)  = cy - C/Y;  

par = par(:);
I =  delta_s*Ks +delta_e*Ke;
IY_ratio = I/Y;

IsIe = delta_s*Ks/(delta_e*Ke);

mom.sp =(zs*ws)/(wu);
mom.rkgdp =(re*Ke + rs*Ks)/Y ;
mom.cy=C/Y;
mom.ky = (Ks+Ke)/Y;
mom.isie =IsIe;
mom.iy = IY_ratio;
    
end
end

