% The main file 
clear  
clc
addpath('Data','Production','Utility','Others');
addpath('Ramsey','Mirrlees','Assignment')
%% Calibration of steady state in 1963 and loading  data
global delta_s delta_e beta
% Global parameters ( production)
alpha = 0.117    ; sigma = 0.401  ;
rho = -0.495       ; delta_s = 0.05  ; % From Greenwood, Hercowitz, Krusell (1997)
delta_e =0.125  ; % Krusell et al. (1997)
 
% First run file Data/data_manage_q.m  and Autor_data.m
%Production parameters
mu0 =0.337;            % initial guess the model we'd like to calibrate
lambda0 =0.344; 

%Utility parameters 
gamma_c =1.5; gamma_n =3;
chi = 2.53;  beta0 = 0.98;
beta = beta0;
vflag =1;    % we use the utility function form u(c)+v(1-n)

parmf0  = [alpha;sigma;mu0;rho;lambda0];
lambda = lambda0;

parmU = [gamma_c; gamma_n;chi;vflag];

%Government tax policy 
load('Data/data.mat')
tau_k = tk_us_ext(1);   % used from McDanial (2007)
tau_n = tn_us_ext(1);   % used from McDanial (2007)
Gr = 0.175;             % average between 1947- 1951
parmT =[tau_k,tau_k,tau_n,Gr ];

%Population settings: assume same population at first
pis0 =0.5;  piu0 = 1-pis0;
zs0 =1;    zu0=1;     q0=1;
% Total skilled workers hold aggregate asset  ratio =  0.436, 
%see Data in Data\wealthpartition.xlsx,  sheet 1989
ssk =0.436/pis0;        
 

% Calibration step
 calibration         



command1 = "Please choose a model to continue: \n ";
command2 = command1 +"benchmark=1; extension =2; show plotting results =3  \n";
command3 = command2 + " (or press other keys to exit the program) :" ;
response = input(command3);
if  response== 1
    fprintf('\n \n ')
    str1 ="Please choose  which model for execution : ";
    str2 =str1 +" Mirrlees(M)/ Ramsey(R)  \n";
    str3 = str2 +" (or press other keys to exit the program) : ";
    response2 = input(str3, 's');
    if  isequal(response2 ,'R')  || isequal(response2,'r')
        main_Ramsey_benchmark
    elseif isequal(response2,'M') ||  isequal(response2,'m')
        main_Mirrlees_benchmark
    else 
        return
    end
elseif response == 2
    str1  ="\n \n \n Please choose  which model for execution :\n ";
    str2 = str1 + "Extended model(C)/Mirrlees(M)/ Ramsey(R)  \n";
    str3 = str2 + "(or press other keys to exit the program) :\n";
    response2 = input(str3, 's');
    if   isequal(response2,'C')  || isequal(response2,'c')
        main_ce_assign
    elseif  isequal(response2,'R')  || isequal(response2,'r')
        main_Ramsey_ext
    elseif  isequal(response2,'M') ||  isequal(response2,'m')
        main_Mirrlees_ext
    else
        return
    end
elseif response == 3
    mkdir("fig")  % create an folder for saving the following figures
    str1 = "\n \n \n Please choose which model for displaying:  \n " ;
    str2 = str1 +"benchmark = 1 /  extended model =2 \n  ";
    str3 = str2 +"(or press other keys to exit the program) :\n";
    response3 = input(str3);
    if  response3 ==1
        Create_Figure_Data
        Create_FigureR_benchmark
        Create_FigureM_benchmark        
    elseif response3 == 2
        Create_Figure_ext
        welfare_compute 
    else
        return
    end
else
    return
end
 